summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/livarot/LivarotDefs.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/livarot/LivarotDefs.h b/src/livarot/LivarotDefs.h
index bf1326338..49f954586 100644
--- a/src/livarot/LivarotDefs.h
+++ b/src/livarot/LivarotDefs.h
@@ -36,7 +36,8 @@ enum
// despite the rounding sheme, this still happen with uber-complex graphs
// note that coordinates are stored in double => double precision for the computation is not even
// enough to get exact results (need quadruple precision, i think).
- shape_input_err = 5 // the function was given an incorrect input (not a polygon, or not eulerian)
+ shape_input_err = 5, // the function was given an incorrect input (not a polygon, or not eulerian)
+ shape_nothing_to_do = 6 // the function had nothing to do (zero offset, etc)
};
// return codes for the find function in the AVL tree (private)